from .types import API

DOMAIN = "https://staging.orijinplusserver.com"
ENDPOINTS = API(DOMAIN)
ENDPOINTS.domain = DOMAIN